#!/usr/bin/env python

# #############################################################################
# HEATMAP of CETP paper
# #############################################################################

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# PREAMBLE
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

from pathlib import Path
# %%%%%%%% imports
import os
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns

# %%%%%%%% plot setting defaults
# add lines between bins
plt.rcParams["patch.force_edgecolor"] = True
sns.set(style='ticks')
# removing boxed axes
plt.rc("axes.spines", top=False, right=False)

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# PATHS
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# paths
data_path = '../MR_data/'

# output
output = '../figures'

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# CONTENT
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

# Data for Figure 2
pval = pd.read_csv(os.path.join(data_path, 'Figure2_pvalues.tsv'), sep='\t',
                    index_col=0)
effect = pd.read_csv(os.path.join(data_path, 'Figure2_estimates.tsv'), sep='\t',
                    index_col=0)

# Data for Figure 5
combined = pd.read_csv(os.path.join(data_path, 'Figure5.tsv'), sep='\t',
                    index_col=0)

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# CONSTANTS
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cmtoinch = 0.393700787
maxpval = 16

###############################################################################
# Figure 2
###############################################################################
col = sns.diverging_palette(190,25, s=80, l=60, n=13)
top_margin = 0.04  # in percentage of the figure height
bottom_margin = 0.04 # in percentage of the figure height
sns.set(font_scale=0.6) # font size
sns.set_context("paper")

fig, ax = plt.subplots(
    figsize=(10 * cmtoinch, 10 * cmtoinch),
    gridspec_kw=dict(top=1-top_margin, bottom=bottom_margin)
)
sns.heatmap(pval, annot=effect, ax=ax, fmt=".3", linewidths=1.0, square=True,
            cmap=col, center=0, mask = pval.isna(),
            vmin = -1*maxpval, vmax=1*maxpval, # lower bound of the colourbar
            robust=True,  annot_kws={"fontsize":4.0} )
ax.set(xlabel='Exposure', ylabel='Outcome')
ax.tick_params(left=False, bottom=True)
ax.collections[0].colorbar.set_label(r"direction $\times -\log_{10}$(p-value)")

plt.savefig(os.path.join(output,'Figure2.pdf'), bbox_inches='tight',
        dpi = 300)
plt.close('all')

###############################################################################
# Figure 3
###############################################################################

lims = [np.floor(np.min(combined.min())), np.ceil(np.max(combined.max()))]
sig = np.where(np.abs(combined) > np.sqrt(-1*np.log10(0.05)), "*", ".")

# #### Actual figures
col = sns.diverging_palette(190,25, s=80, l=60, n=13)
top_margin = 0.04  # in percentage of the figure height
bottom_margin = 0.04 # in percentage of the figure height
sns.set(font_scale=0.6) # font size
sns.set_context("paper")

cg = sns.clustermap(combined.dropna(), fmt=".3", linewidths=1.0,
                figsize=(8 * cmtoinch, 8 * cmtoinch), cmap=col,
                annot = sig, cbar_pos=(0.09, 0.08, 0.03, .2),
                center=0, col_cluster=True, row_cluster=True,
                vmin=lims[0], vmax=lims[1],
                    method = 'single',
                    metric = 'euclidean',
               )
cg.ax_cbar.axes.yaxis.set_label_text(r"dir $\times -\log_{10}$(p)", fontsize=7)
cg.ax_cbar.axes.yaxis.set_label_position('left')
cg.ax_cbar.tick_params(labelsize=5)

plt.savefig(os.path.join(output,'Figure5.pdf'), bbox_inches='tight',
        dpi = 300)
plt.close('all')
