#!/usr/bin/env Rscript

###############################################################################
# POLAR FIGURE of CETP NMR results 
###############################################################################
rm(list = ls(all = T))
options(repos=c(CRAN ="https://cloud.r-project.org/")) #setting repositories

source("helper_code/Premable.R")
library(dplyr)
library(readxl)

# output
output = '../figures/'

############################################################
# LOADING DATA
############################################################

cetp <- read_delim('../MR_data/Figure4_CETP.tsv', delim='\t')
pcsk9 <- read_delim('../MR_data/Figure4_PCSK9.tsv', delim='\t')
lab_order <- read_tsv('../MR_data/phenogram.csv')
dict <- readxl::read_xlsx('../MR_data/nmrlabels.xlsx', sheet = 5)
dict <- dict[!duplicated(dict$MET),]

#%%%%%%%%%% code in the CETP decreasing direction
cetp$point <- -1 * cetp$point
cetp$newpval <- sign(cetp$point) * -1 * log10(cetp$pvalue)
cetp$newpval[cetp$newpval == Inf] <- 16
cetp$newpval[cetp$newpval == -Inf] <- -16

#%%%%%%%%%% code in the PCSK9 decreasing direction
pcsk9$point <- -1 * pcsk9$point
pcsk9$newpval <- sign(pcsk9$point) * -1 * log10(pcsk9$pvalue)
pcsk9$newpval[pcsk9$newpval == Inf] <- 16
pcsk9$newpval[pcsk9$newpval == -Inf] <- -16

#############################################################
## BETTER LABELS
#############################################################

#%%%%%%%%%%%%%%%%%%%%%%%%%% CETP
cetp$labels <- gsub('_', ' ', sub('_pruned', '', cetp$X1))
cetp$MET <- gsub(' ', '', cetp$labels)
cetp2 <- merge(cetp, dict, by = 'MET', all=F)

cetp2$group <- trimws((gsub(".* - ","",cetp2$LABEL4)))
cetp2$group2 <- trimws((gsub(".* - ","",cetp2$LABEL)))
cetp2 <- cetp2[!cetp2$group == 'NA',]

#%%%%%%%%%%%%%%%%%%%%%%%%%% PCSK9
pcsk9$labels <- gsub('_', ' ', sub('_pruned', '', pcsk9$X1))
pcsk9$MET <- gsub(' ', '', pcsk9$labels)
pcsk92 <- merge(pcsk9, dict, by = 'MET')
pcsk92$group <- trimws((gsub(".* - ","",pcsk92$LABEL4)))
pcsk92$group2 <- trimws((gsub(".* - ","",pcsk92$LABEL)))
pcsk92 <- pcsk92[!pcsk92$group == 'NA',]

############################################################
# CONSTANTS
############################################################
cmtoinch = 0.393700787

# constants
labs <- 1.5
# lims <- range(combined$newpval)
lty <- 1
ls <- 0.2

w = 14 * cmtoinch
h = 14 * cmtoinch

col1 <- c("#00AFBB", "#E7B800", "#FC4E07","#52854C")

############################################################
# GRAPH 
############################################################
cetp2$target = 'CETP'
pcsk92$target = 'PCSK9'
csel_combi <- c('target', 'labels', 'newpval')

combined <- rbind(cetp2[, csel_combi], pcsk92[, csel_combi])
combined$target <- factor(combined$target)
combined$labels <- as.factor(combined$labels)
combined$dir <- sign(combined$newpval)

# factor order
lab_order2 <- trimws((gsub("_"," ",lab_order$UCLEB)))
combined$labels <- factor(combined$labels, 
                    levels = lab_order2)
combined$labels <- factor(combined$labels)

# labels
levels_nmr <- levels(combined$labels)
mid <- floor(length(levels_nmr)/2)
firstlabs <- combined[combined$labels %in% levels_nmr[1:mid],]
firstlabs$labels <- factor(firstlabs$labels)
secondlabs <- combined[combined$labels %in% levels_nmr[(mid+1):length(levels_nmr)],]
secondlabs$labels <- factor(secondlabs$labels)

hist_over <- function(input, a = 0.55){
    ggplot(data =input, aes(x = labels, y = newpval, fill = target)) +
            geom_hline(yintercept = c(-1,0, 1) *log10(0.05), linetype=lty,
                col = "black", size=ls)+
            geom_bar(stat = "identity", position='identity', alpha = a,
            col = 'black', size = 0.2) +
            theme(
                    axis.title.y = element_blank(),
                    axis.ticks.y = element_blank(),
                    axis.text.y = element_text(size=5),
                    axis.text.x = element_text(size=7),
                    axis.title.x = element_text(size=8),
                    axis.line = element_blank(),
                    panel.background = element_rect(fill = 'transparent', size = 0.2),
                    panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
                    plot.margin = unit(c(1,1,1,1), "mm")) +
            coord_flip()
}

p1 <- hist_over(firstlabs) + labs(fill = "Drug target", y = 'Direction times p-value') +
        scale_fill_manual(values = col1[c(1,3)]) +
        theme(
            legend.position = c(0.80, 0.95),
            legend.text=element_text(size=6),
            legend.title=element_text(size=7),
            legend.key.size = unit(0.7,"line"),
            panel.background = element_rect(fill = 'grey95')
        ) + scale_x_discrete(limits = rev(levels(firstlabs$labels)))
p2 <- hist_over(secondlabs) + labs(fill = "Drug target",
        y = 'Direction times p-value') +
        scale_fill_manual(values = col1[c(1,3)]) +
        theme(
            legend.position = 'None',
            panel.background = element_rect(fill = 'grey95')
        ) + scale_x_discrete(limits = rev(levels(secondlabs$labels)))

bar_alpha <- cowplot::plot_grid(p1, p2, rel_widths=c(1,1))
ggsave(paste0(output, 'Figure4.pdf'),bar_alpha,  units = 'in', width=w, height=h)
